#
# spec file for package xemacs-packages
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xemacs-packages
#!BuildIgnore:  xemacs-packages-info xemacs-packages-el xemacs-packages
BuildRequires:  compface
BuildRequires:  db-devel
%if 0%{?suse_version} >= 1110
BuildRequires:  fdupes
%endif
BuildRequires:  freetype2-devel
BuildRequires:  gcc-c++
BuildRequires:  krb5
BuildRequires:  libpng-devel
BuildRequires:  libtiff-devel
BuildRequires:  openldap2-devel
BuildRequires:  texlive
BuildRequires:  texlive-latex
BuildRequires:  unzip
BuildRequires:  update-desktop-files
BuildRequires:  xemacs-el > 21.5.29
%if 0%{?suse_version} >= 1220
BuildRequires:  bdftopcf
BuildRequires:  mkfontdir
%else
BuildRequires:  xorg-x11
BuildRequires:  xorg-x11-devel
%endif
%if %suse_version > 1220
BuildRequires:  glibc-locale
BuildRequires:  info
BuildRequires:  makeinfo
BuildRequires:  par
BuildRequires:  texinfo
BuildRequires:  texlive-amsfonts
BuildRequires:  texlive-cm-super
BuildRequires:  texlive-ec
%endif
URL:            http://www.xemacs.org
Provides:       xemacs:%{_datadir}/xemacs/xemacs-packages/etc/auctex/style/amsart.elc
Obsoletes:      Mule-UCS-xemacs
Obsoletes:      apel-xemacs <= 10.7
Obsoletes:      mule-ucs-xemacs
Version:        20130822
Release:        15.4
Requires:       /usr/bin/env
#
# HG version >= 1.9.3
#   hg --version
#   hg clone https://bitbucket.org/xemacs/xemacs-packages packages
#   cd packages/
# Check for last version
#   head -n 1 ChangeLog
#   hg archive -S -p packages -X '.hg*' -X '.cvs*' -t tbz2 ../xemacs-sumo-<version>.tar.bz
#
Source1:        xe-list.el
Source3:        texi2utf8
Source0:        %{name}-%{version}.tar.bz2
Source20:       xemacs-packages-rpmlintrc
# PATCH-FIX-OPENSUSE xemacs-packages-expand-kw.diff ailin.nemui@gmail.com -- expand CVS keywords which does not happen in hg (can be removed when new packages get releases from hg)
Patch1:         xemacs-packages-expand-kw.diff
Patch2:         xemacs-packages.patch
# keep in sync with the similar patch to the app-defaults in the main xemacs package:
Patch3:         app-defaults.patch
Patch4:         packages-cvs-xemacs-sumo-2005-12-08-apel.patch
Patch5:         edict-utf-8.patch
Patch6:         packages-cvs-xemacs-sumo-2005-12-08-diff-mode.patch
Patch7:         gnus-utf-8.patch
Patch11:        packages-cvs-xemacs-sumo-2002-03-29-ps-print.patch
Patch15:        packages-cvs-sumo-2002-09-19-comint.patch
Patch17:        packages-cvs-sumo-2004-02-02-awk.patch
Patch18:        dinbrief.patch
Patch19:        disable-skk.patch
Patch24:        texi-coding.patch
Patch28:        texi.patch
Patch32:        bugzilla-183805-missing-autoload-cookies.patch
Patch34:        mode-local.patch
Patch35:        xemacs-packages-20130822-tramp.patch
Patch36:        reproducible.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
Summary:        XEmacs Packages
License:        GPL-3.0-or-later
Group:          Productivity/Editors/Emacs
%define _default_patch_fuzz 2

%description -n xemacs-packages
A collection of additional lisp packages for XEmacs. You must install
this package when you want to use the XEmacs package, they are needed
for most non-trivial XEmacs functions.



Authors:
--------
    Chuck Thompson   <cthomp@cs.uiuc.edu>
    Ben Wing <wing@666.com>
    and many other contributors

%package     -n xemacs-packages-el
Summary:        Emacs-Lisp source files for the XEmacs packages
Group:          Productivity/Editors/Emacs
Provides:       xemacs-el:%{_datadir}/xemacs/xemacs-packages/etc/auctex/style/amsart.el

%description -n xemacs-packages-el
Most Emacs-Lisp source files are not needed for running XEmacs. Most of
them are also available in byte compiled form and therefore not
necessary at runtime. The true XEmacs addict will install them
nevertheless because it is often useful and enlightening to have a look
at the Lisp sources.



Authors:
--------
    Chuck Thompson   <cthomp@cs.uiuc.edu>
    Ben Wing <wing@666.com>
    and many other contributors

%package     -n xemacs-packages-info
Summary:        Info Files for the XEmacs Packages
Group:          Productivity/Editors/Emacs
Provides:       xemacs-info:%{_datadir}/xemacs/xemacs-packages/info/auctex.info.gz

%description -n xemacs-packages-info
This package contains all the info files for the extra packages for
XEmacs. All these files can be read online with XEmacs and describe
XEmacs and some of its modes.



Authors:
--------
    Chuck Thompson   <cthomp@cs.uiuc.edu>
    Ben Wing <wing@666.com>
    and many other contributors

%prep
%setup -q
%patch -P 1   -p1 -b .keywords
find -name '*.pl' -o -name file-newer | \
  xargs -r sed -ri '1 {s@(^#[[:blank:]]*\!)(.*/perl5?)@\1/usr/bin/perl@p}'
chmod -R u+rw,g+r,o+r .
%patch -P 2   -p1 -b .packages
%patch -P 3   -p1 -b .app-defaults
%patch -P 4   -p1 -b .apel
%patch -P 5   -p1 -b .edict-utf-8
%patch -P 6   -p1 -b .diff-mode
%patch -P 7   -p1 -b .gnus-utf-8
%patch -P 11  -p1 -b .psprint
#%patch -P 15 -p1 -b .comint
%patch -P 17  -p1 -b .awk
%patch -P 18  -p1 -b .dinbrief
%patch -P 19  -p1 -b .disable-skk
%patch -P 24  -p1 -b .texi-coding
%patch -P 28  -p1 -b .texi-patch
%patch -P 32  -p1 -b .cookie
%patch -P 34  -p1 -b .mode-local
# PATCH-FIX-SUSE boo#857207 -- xemacs tramp ssh completion returns "Wrong type argument: symbolp, ..."
%patch -P 35  -p1 -b .tramp
%patch -P 36 -p1
rm -vf xemacs-packages/tramp/texi/tramp.texi.tramp
chmod 755 %{S:3}
%{S:3}

%build
unset ${!LC_*}
export LC_ALL=POSIX
cp Local.rules.template Local.rules
make %{?_smp_mflags} distclean   XEMACS_INSTALLED_PACKAGES_ROOT=%{_datadir}/xemacs MAKEINFO="makeinfo --force"
make                 autoloads   XEMACS_INSTALLED_PACKAGES_ROOT=%{_datadir}/xemacs MAKEINFO="makeinfo --force"
make                 bytecompile XEMACS_INSTALLED_PACKAGES_ROOT=%{_datadir}/xemacs MAKEINFO="makeinfo --force"

%install
unset ${!LC_*}
export LC_ALL=POSIX
make %{?_smp_mflags} install     XEMACS_INSTALLED_PACKAGES_ROOT=%{buildroot}%{_datadir}/xemacs MAKEINFO="makeinfo --force"

# quick hack to install latin-unity-tables.el because latin-unity-tables.elc
# is not built:
install -m 644 mule-packages/latin-unity/latin-unity-tables.el \
    %{buildroot}%{_datadir}/xemacs/mule-packages/lisp/latin-unity/latin-unity-tables.el
gzip -n --best %{buildroot}%{_datadir}/xemacs/xemacs-packages/info/*
gzip -n --best %{buildroot}%{_datadir}/xemacs/mule-packages/info/*
######################################################################
# ugly workaround to avoid the messages
#     $ xemacs -q
#     Loading ediff-hook...
#     Loading ediff-hook...done
# on standard out when starting xemacs
echo "(require 'ediff-hook)" > %{buildroot}%{_datadir}/xemacs/xemacs-packages/lisp/ediff/auto-autoloads.el.new
cat %{buildroot}%{_datadir}/xemacs/xemacs-packages/lisp/ediff/auto-autoloads.el \
    >> %{buildroot}%{_datadir}/xemacs/xemacs-packages/lisp/ediff/auto-autoloads.el.new
mv  %{buildroot}%{_datadir}/xemacs/xemacs-packages/lisp/ediff/auto-autoloads.el.new \
    %{buildroot}%{_datadir}/xemacs/xemacs-packages/lisp/ediff/auto-autoloads.el
echo "(require 'advice)"     >  %{buildroot}%{_datadir}/xemacs/xemacs-packages/lisp/semantic/auto-autoloads.el.new
echo "(require 'mode-local)" >> %{buildroot}%{_datadir}/xemacs/xemacs-packages/lisp/semantic/auto-autoloads.el.new
cat %{buildroot}%{_datadir}/xemacs/xemacs-packages/lisp/semantic/auto-autoloads.el \
    >> %{buildroot}%{_datadir}/xemacs/xemacs-packages/lisp/semantic/auto-autoloads.el.new
mv  %{buildroot}%{_datadir}/xemacs/xemacs-packages/lisp/semantic/auto-autoloads.el.new \
    %{buildroot}%{_datadir}/xemacs/xemacs-packages/lisp/semantic/auto-autoloads.el
######################################################################
#
mkdir -p %{buildroot}%{_datadir}/xemacs/xemacs-packages/etc/auctex/doc
install -m 644 xemacs-packages/auctex/doc/tex-ref.dvi \
	 %{buildroot}%{_datadir}/xemacs/xemacs-packages/etc/auctex/doc/
mkdir -p %{buildroot}%{_datadir}/xemacs/xemacs-packages/man/auctex
install -m 644 xemacs-packages/auctex/{CHANGES,FAQ,README,TODO} \
	 %{buildroot}%{_datadir}/xemacs/xemacs-packages/man/auctex/
######################################################################
# Some .elc's are not needed:
find  %{buildroot}%{_datadir}/xemacs/ -name '_pkg.elc'   | xargs -r rm -f
find  %{buildroot}%{_datadir}/xemacs/ -name 'auto-autoloads.elc' | xargs -r rm -f
# add Japanese translations for liece menus to Japanese app-defaults:
chmod u+w %{buildroot}%{_datadir}/xemacs/mule-packages/etc/app-defaults/ja/Emacs
cat xemacs-packages/liece/etc/Emacs.ad >> %{buildroot}%{_datadir}/xemacs/mule-packages/etc/app-defaults/ja/Emacs
# delete a riece file which shouldn't have been installed:
rm %{buildroot}%{_datadir}/xemacs/xemacs-packages/lisp/riece/riece-package-info.el.in
# Make symlinks for international app-defaults:
ln -sf de %{buildroot}%{_datadir}/xemacs/mule-packages/etc/app-defaults/de_DE
ln -sf de %{buildroot}%{_datadir}/xemacs/mule-packages/etc/app-defaults/de_DE@euro
ln -sf fr %{buildroot}%{_datadir}/xemacs/mule-packages/etc/app-defaults/fr_FR
ln -sf fr %{buildroot}%{_datadir}/xemacs/mule-packages/etc/app-defaults/fr_FR@euro
ln -sf sv %{buildroot}%{_datadir}/xemacs/mule-packages/etc/app-defaults/sv_SE
ln -sf sv %{buildroot}%{_datadir}/xemacs/mule-packages/etc/app-defaults/sv_SE@euro
ln -sf ja %{buildroot}%{_datadir}/xemacs/mule-packages/etc/app-defaults/ja_JP
ln -sf ja %{buildroot}%{_datadir}/xemacs/mule-packages/etc/app-defaults/ja_JP.ujis
ln -sf ja %{buildroot}%{_datadir}/xemacs/mule-packages/etc/app-defaults/ja_JP.EUC
ln -sf ja %{buildroot}%{_datadir}/xemacs/mule-packages/etc/app-defaults/ja_JP.eucJP
ln -sf ro %{buildroot}%{_datadir}/xemacs/mule-packages/etc/app-defaults/ro_RO
# create international app-defaults for UTF-8 locales:
pushd %{buildroot}%{_datadir}/xemacs/mule-packages/etc/app-defaults/
    for i in de_DE fr_FR ja_JP sv_SE ro_RO
    do
	mkdir $i.UTF-8
	iconv -f $(LC_ALL=$i locale charmap) -t UTF-8 < $i/Emacs > $i.UTF-8/Emacs
        perl -pi -e 's/-\*- (mode:.*)?coding:.*-\*-/-\*- \1coding: utf-8 -\*-/' $i.UTF-8/Emacs
    done
popd
# generate info/dir files:
xemacs -batch -f Info-batch-rebuild-dir \
                 %{buildroot}%{_datadir}/xemacs/xemacs-packages/info/ \
		 %{buildroot}%{_datadir}/xemacs/mule-packages/info/
for i in %{buildroot}%{_datadir}/xemacs/*/info/dir
do
    perl -pi -e "s|%{buildroot}||" $i
done
mkdir -p %{buildroot}%{_defaultdocdir}/%{name}
ln -s %{_datadir}/xemacs/xemacs-packages/etc \
      %{buildroot}/%{_defaultdocdir}/%{name}/xemacs-packages
ln -s %{_datadir}/xemacs/mule-packages/etc \
      %{buildroot}/%{_defaultdocdir}/%{name}/mule-packages
# Remove unneeded files
rm -f %{buildroot}%{_datadir}/xemacs/xemacs-packages/lisp/w3/README.NT \
      %{buildroot}%{_datadir}/xemacs/xemacs-packages/lisp/w3/README.VMS
rm -f %{buildroot}%{_datadir}/xemacs/mule-packages/etc/mule-ucs/mule-ucs.texi
find %{buildroot}%{_datadir}/xemacs/xemacs-packages/etc/ -name INSTALL | \
    xargs -r rm -vf
find %{buildroot}%{_datadir}/xemacs/xemacs-packages/lisp/ -name INSTALL | \
    xargs -r rm -vf
# Move docs from lisp to etc directories
for doc in \
	   hyperbole/{{_,.}hypb,DEMO,GNUmakefile.id,MANIFEST,file-newer,smart-clib-sym} \
	   hyperbole/kotl/{EXAMPLE.kotl,MANIFEST} \
	   oo-browser/{BR-{COPY,FEATURES,README,RELEASE,VERSION},Make-Env,Makefile,oo-browser.texi}
do
    src=%{buildroot}%{_datadir}/xemacs/xemacs-packages/lisp/$doc
    case "$doc" in
    auctex*) dst=%{buildroot}%{_datadir}/xemacs/xemacs-packages/etc/auctex/doc/${doc##*/} ;;
    *)	     dst=%{buildroot}%{_datadir}/xemacs/xemacs-packages/etc/$doc
    esac
    case "${doc##*/}" in
    _*) rm -vf $src ;;
    .*) rm -vf $src ;;
    *.texi)
	rm -vf $src ;;
    GNUmakefile*|Makefile)
	rm -vf $src
    esac
    test -e $src || continue
    test -d ${dst%%/*} || mkdir -p ${dst%%/*}
    mv -vf $src $dst
done
# Correct permissions
chmod a-x %{buildroot}%{_datadir}/xemacs/xemacs-packages/etc/text-modes/*.xpm
chmod a-x %{buildroot}%{_datadir}/xemacs/xemacs-packages/etc/jde/doc/html/jde-ug/images/*.gif
chmod a-x %{buildroot}%{_datadir}/xemacs/xemacs-packages/etc/jde/doc/src/jde-ug/images/*.gif
chmod a-x %{buildroot}%{_datadir}/xemacs/xemacs-packages/lisp/text-modes/*.el
chmod a-x %{buildroot}%{_datadir}/xemacs/xemacs-packages/lisp/vm/*.el
chmod a-x %{buildroot}%{_datadir}/xemacs/xemacs-packages/lisp/jde/*.el
chmod a-x %{buildroot}%{_datadir}/xemacs/xemacs-packages/lisp/ede/*.el
# File duplicates
%if 0%{?suse_version} >= 1110
fdupes -q -o name -r -1 %{buildroot}%{_datadir}/xemacs/ | while read first second; do
    case "${first}" in
    *.el*)  continue ;;
    *.texi) continue
    esac
    target=
    file=
    for t in $first $second; do
	case "$t" in
	*/lisp/*)
	    file="$t"
	    continue
	esac
    done
    if test -n "$file" ; then
	for t in $first $second; do
	    test "$t" = "$file" && continue
	    target="${target:+$target }$t"
	done
    else
	file="$first"
	target="$second"
    fi
    for t in ${target} ; do
	ln -sf ${file#%{buildroot}} ${t}
    done
done
%endif
# generate file lists:
find %{buildroot} \
    \( \( \( -not -type d \) -printf '%%p\n' \) \
               -o \( -type d -printf '%%p/\n' \) \) \
	| sort -t / | uniq | sed "s|^%{buildroot}||" > xe-list
xemacs -batch -l $RPM_SOURCE_DIR/xe-list.el -f xe-list-generate-list-files
cat xe-list-el-without-elc xe-list-elc-without-el xe-list-elc-with-el \
    >> xe-list-el-without-elc_xe-list-elc-without-el_xe-list-elc-with-el

%clean
#[ "%{buildroot}" != "/" ] && [ -d %{buildroot} ] && rm -rf %{buildroot}

%files -f xe-list-el-without-elc_xe-list-elc-without-el_xe-list-elc-with-el
%defattr(-,root,root)
%dir %{_docdir}/%{name}/
%{_docdir}/%{name}/*
%dir %{_datadir}/xemacs/
%dir %{_datadir}/xemacs/mule-packages/
%dir %{_datadir}/xemacs/mule-packages/etc/
%dir %{_datadir}/xemacs/mule-packages/etc/app-defaults/
%dir %{_datadir}/xemacs/mule-packages/etc/app-defaults/de/
%config %{_datadir}/xemacs/mule-packages/etc/app-defaults/de/Emacs
%{_datadir}/xemacs/mule-packages/etc/app-defaults/de_DE
%dir %{_datadir}/xemacs/mule-packages/etc/app-defaults/de_DE.UTF-8/
%config %{_datadir}/xemacs/mule-packages/etc/app-defaults/de_DE.UTF-8/Emacs
%{_datadir}/xemacs/mule-packages/etc/app-defaults/de_DE@euro
%dir %{_datadir}/xemacs/mule-packages/etc/app-defaults/fr/
%config %{_datadir}/xemacs/mule-packages/etc/app-defaults/fr/Emacs
%{_datadir}/xemacs/mule-packages/etc/app-defaults/fr_FR
%dir %{_datadir}/xemacs/mule-packages/etc/app-defaults/fr_FR.UTF-8/
%config %{_datadir}/xemacs/mule-packages/etc/app-defaults/fr_FR.UTF-8/Emacs
%{_datadir}/xemacs/mule-packages/etc/app-defaults/fr_FR@euro
%dir %{_datadir}/xemacs/mule-packages/etc/app-defaults/ja/
%config %{_datadir}/xemacs/mule-packages/etc/app-defaults/ja/Emacs
%{_datadir}/xemacs/mule-packages/etc/app-defaults/ja_JP
%{_datadir}/xemacs/mule-packages/etc/app-defaults/ja_JP.EUC
%dir %{_datadir}/xemacs/mule-packages/etc/app-defaults/ja_JP.UTF-8/
%config %{_datadir}/xemacs/mule-packages/etc/app-defaults/ja_JP.UTF-8/Emacs
%{_datadir}/xemacs/mule-packages/etc/app-defaults/ja_JP.eucJP
%{_datadir}/xemacs/mule-packages/etc/app-defaults/ja_JP.ujis
%dir %{_datadir}/xemacs/mule-packages/etc/app-defaults/ro/
%config %{_datadir}/xemacs/mule-packages/etc/app-defaults/ro/Emacs
%{_datadir}/xemacs/mule-packages/etc/app-defaults/ro_RO
%dir %{_datadir}/xemacs/mule-packages/etc/app-defaults/ro_RO.UTF-8/
%config %{_datadir}/xemacs/mule-packages/etc/app-defaults/ro_RO.UTF-8/Emacs
%dir %{_datadir}/xemacs/mule-packages/etc/app-defaults/sv/
%config %{_datadir}/xemacs/mule-packages/etc/app-defaults/sv/Emacs
%{_datadir}/xemacs/mule-packages/etc/app-defaults/sv_SE
%dir %{_datadir}/xemacs/mule-packages/etc/app-defaults/sv_SE.UTF-8/
%config %{_datadir}/xemacs/mule-packages/etc/app-defaults/sv_SE.UTF-8/Emacs
%{_datadir}/xemacs/mule-packages/etc/app-defaults/sv_SE@euro
%dir %{_datadir}/xemacs/mule-packages/etc/edict/
%doc %{_datadir}/xemacs/mule-packages/etc/edict/ChangeLog.096
%doc %{_datadir}/xemacs/mule-packages/etc/edict/README
%doc %{_datadir}/xemacs/mule-packages/etc/edict/README.096
%doc %{_datadir}/xemacs/mule-packages/etc/edict/edict.doc.096
%doc %{_datadir}/xemacs/mule-packages/etc/edict/edictj.demo
%dir %{_datadir}/xemacs/mule-packages/etc/latin-unity/
%doc %{_datadir}/xemacs/mule-packages/etc/latin-unity/BLURB
%doc %{_datadir}/xemacs/mule-packages/etc/latin-unity/ChangeLog
%doc %{_datadir}/xemacs/mule-packages/etc/latin-unity/Makefile
%doc %{_datadir}/xemacs/mule-packages/etc/latin-unity/README
%dir %{_datadir}/xemacs/mule-packages/etc/mule-doc/
%doc %{_datadir}/xemacs/mule-packages/etc/mule-doc/*
%dir %{_datadir}/xemacs/mule-packages/etc/mule-ucs/
%doc %{_datadir}/xemacs/mule-packages/etc/mule-ucs/ChangeLog
%doc %{_datadir}/xemacs/mule-packages/etc/mule-ucs/Makefile
%doc %{_datadir}/xemacs/mule-packages/etc/mule-ucs/MuleUni.txt
%doc %{_datadir}/xemacs/mule-packages/etc/mule-ucs/README
%doc %{_datadir}/xemacs/mule-packages/etc/mule-ucs/README.Unicode
%doc %{_datadir}/xemacs/mule-packages/etc/mule-ucs/README.XEmacs
%doc %{_datadir}/xemacs/mule-packages/etc/mule-ucs/mule-ucs.sgml
%dir %{_datadir}/xemacs/mule-packages/etc/mule-ucs/reldata/
%doc %{_datadir}/xemacs/mule-packages/etc/mule-ucs/type.txt
%dir %{_datadir}/xemacs/mule-packages/etc/mule/
%doc %{_datadir}/xemacs/mule-packages/etc/mule/FAQ-Mule
%doc %{_datadir}/xemacs/mule-packages/etc/mule/FAQ-Mule.cn
%doc %{_datadir}/xemacs/mule-packages/etc/mule/FAQ-Mule.ja
%doc %{_datadir}/xemacs/mule-packages/etc/mule/FAQ-Mule.kr
%doc %{_datadir}/xemacs/mule-packages/etc/mule/FAQ-Mule.th
%doc %{_datadir}/xemacs/mule-packages/etc/mule/Makefile.in
%doc %{_datadir}/xemacs/mule-packages/etc/mule/TUTORIAL.kr
%doc %{_datadir}/xemacs/mule-packages/etc/mule/VERSIONS
%doc %{_datadir}/xemacs/mule-packages/etc/mule/coco.1
%doc %{_datadir}/xemacs/mule-packages/etc/mule/demo.ps
%doc %{_datadir}/xemacs/mule-packages/etc/mule/m2ps.1
%doc %{_datadir}/xemacs/mule-packages/etc/mule/m2ps.1.in
%doc %{_datadir}/xemacs/mule-packages/etc/mule/m2ps.ps
%doc %{_datadir}/xemacs/mule-packages/etc/mule/mule-refcard.tex
%doc %{_datadir}/xemacs/mule-packages/etc/mule/mule.1
%{_datadir}/xemacs/mule-packages/etc/mule/mule.xbm
%{_datadir}/xemacs/mule-packages/etc/mule/tom.xbm
%dir %{_datadir}/xemacs/mule-packages/etc/start-files/
%dir %{_datadir}/xemacs/mule-packages/etc/start-files/fr/
%dir %{_datadir}/xemacs/mule-packages/etc/start-files/ja/
%dir %{_datadir}/xemacs/mule-packages/etc/start-files/ro/
%dir %{_datadir}/xemacs/mule-packages/etc/start-files/French/
%dir %{_datadir}/xemacs/mule-packages/etc/start-files/Japanese/
%dir %{_datadir}/xemacs/mule-packages/etc/start-files/Romanian/
%dir %{_datadir}/xemacs/mule-packages/lisp/
%dir %{_datadir}/xemacs/mule-packages/lisp/edict/
%doc %{_datadir}/xemacs/mule-packages/lisp/edict/ChangeLog
%doc %{_datadir}/xemacs/mule-packages/lisp/edict/Makefile.GNU
%dir %{_datadir}/xemacs/mule-packages/lisp/egg-its/
%doc %{_datadir}/xemacs/mule-packages/lisp/egg-its/ChangeLog
%{_datadir}/xemacs/mule-packages/lisp/egg-its/eggrc-sj3
%{_datadir}/xemacs/mule-packages/lisp/egg-its/eggrc-wnn
%dir %{_datadir}/xemacs/mule-packages/lisp/latin-euro-standards/
%doc %{_datadir}/xemacs/mule-packages/lisp/latin-euro-standards/ChangeLog
%dir %{_datadir}/xemacs/mule-packages/lisp/latin-unity/
%doc %{_datadir}/xemacs/mule-packages/lisp/latin-unity/ChangeLog
%dir %{_datadir}/xemacs/mule-packages/lisp/leim/
%doc %{_datadir}/xemacs/mule-packages/lisp/leim/ChangeLog
%dir %{_datadir}/xemacs/mule-packages/lisp/leim/quail/
%dir %{_datadir}/xemacs/mule-packages/lisp/locale/
%doc %{_datadir}/xemacs/mule-packages/lisp/locale/ChangeLog
%dir %{_datadir}/xemacs/mule-packages/lisp/lookup/
%doc %{_datadir}/xemacs/mule-packages/lisp/lookup/ChangeLog
%dir %{_datadir}/xemacs/mule-packages/lisp/mule-base/
%doc %{_datadir}/xemacs/mule-packages/lisp/mule-base/ChangeLog
%dir %{_datadir}/xemacs/mule-packages/lisp/mule-ucs/
%doc %{_datadir}/xemacs/mule-packages/lisp/mule-ucs/ChangeLog
%dir %{_datadir}/xemacs/mule-packages/man/
%dir %{_datadir}/xemacs/mule-packages/man/latin-euro-standards/
%doc %{_datadir}/xemacs/mule-packages/man/latin-euro-standards/latin-euro-standards.texi
%dir %{_datadir}/xemacs/mule-packages/man/latin-unity/
%doc %{_datadir}/xemacs/mule-packages/man/latin-unity/latin-unity.texi
%dir %{_datadir}/xemacs/mule-packages/man/lookup/
%doc %{_datadir}/xemacs/mule-packages/man/lookup/lookup.texi
%doc %{_datadir}/xemacs/mule-packages/man/lookup/lookup-guide.texi
%dir %{_datadir}/xemacs/mule-packages/man/mule-ucs/
%doc %{_datadir}/xemacs/mule-packages/man/mule-ucs/mule-ucs.texi
%dir %{_datadir}/xemacs/mule-packages/pkginfo/
%{_datadir}/xemacs/mule-packages/pkginfo/*
%dir %{_datadir}/xemacs/xemacs-packages/
%dir %{_datadir}/xemacs/xemacs-packages/etc/
%{_datadir}/xemacs/xemacs-packages/etc/BABYL
%dir %{_datadir}/xemacs/xemacs-packages/etc/auctex/
%dir %{_datadir}/xemacs/xemacs-packages/etc/auctex/doc/
%doc %{_datadir}/xemacs/xemacs-packages/etc/auctex/doc/*.dvi
%dir %{_datadir}/xemacs/xemacs-packages/etc/auctex/images/
%{_datadir}/xemacs/xemacs-packages/etc/auctex/images/*.xpm
%{_datadir}/xemacs/xemacs-packages/etc/auctex/images/*.xbm
%dir %{_datadir}/xemacs/xemacs-packages/etc/auctex/style/
%dir %{_datadir}/xemacs/xemacs-packages/etc/auctex/latex/
%{_datadir}/xemacs/xemacs-packages/etc/auctex/latex/pr*.def
%{_datadir}/xemacs/xemacs-packages/etc/auctex/latex/prauctex.cfg
%{_datadir}/xemacs/xemacs-packages/etc/auctex/latex/preview.sty
%dir %{_datadir}/xemacs/xemacs-packages/etc/bbdb/
%{_datadir}/xemacs/xemacs-packages/etc/bbdb/bbdb-areacode-split.pl
%{_datadir}/xemacs/xemacs-packages/etc/bbdb/bbdb-cid.pl
%{_datadir}/xemacs/xemacs-packages/etc/bbdb/bbdb-srv.pl
%{_datadir}/xemacs/xemacs-packages/etc/bbdb/bbdb-unlazy-lock.pl
%dir %{_datadir}/xemacs/xemacs-packages/etc/bbdb/tex/
%doc %{_datadir}/xemacs/xemacs-packages/etc/bbdb/tex/bbdb-cols.tex
%doc %{_datadir}/xemacs/xemacs-packages/etc/bbdb/tex/bbdb-print-brief.tex
%doc %{_datadir}/xemacs/xemacs-packages/etc/bbdb/tex/bbdb-print.tex
%doc %{_datadir}/xemacs/xemacs-packages/etc/calccard.tex
%dir %{_datadir}/xemacs/xemacs-packages/etc/e/
%doc %{_datadir}/xemacs/xemacs-packages/etc/e/README
%{_datadir}/xemacs/xemacs-packages/etc/e/emancs
%{_datadir}/xemacs/xemacs-packages/etc/e/emancs.ti
%{_datadir}/xemacs/xemacs-packages/etc/e/eterm
%{_datadir}/xemacs/xemacs-packages/etc/e/eterm.ti
%dir %{_datadir}/xemacs/xemacs-packages/etc/easypg/
%{_datadir}/xemacs/xemacs-packages/etc/easypg/*
%dir %{_datadir}/xemacs/xemacs-packages/etc/ecb/
%{_datadir}/xemacs/xemacs-packages/etc/ecb/*
%dir %{_datadir}/xemacs/xemacs-packages/etc/ediff/
%{_datadir}/xemacs/xemacs-packages/etc/ediff/*
%{_datadir}/xemacs/xemacs-packages/etc/edt-user.doc
%{_datadir}/xemacs/xemacs-packages/etc/emerge.txt
%{_datadir}/xemacs/xemacs-packages/etc/enriched.doc
%dir %{_datadir}/xemacs/xemacs-packages/etc/erc/
%{_datadir}/xemacs/xemacs-packages/etc/erc/*
%dir %{_datadir}/xemacs/xemacs-packages/etc/ezimage
%{_datadir}/xemacs/xemacs-packages/etc/ezimage/*
%{_datadir}/xemacs/xemacs-packages/etc/forms-d2.dat
%dir %{_datadir}/xemacs/xemacs-packages/etc/frame-icon/
%{_datadir}/xemacs/xemacs-packages/etc/frame-icon/*
%dir %{_datadir}/xemacs/xemacs-packages/etc/gnats/
%{_datadir}/xemacs/xemacs-packages/etc/gnats/categories
%{_datadir}/xemacs/xemacs-packages/etc/gnats/xemacs.org
%dir %{_datadir}/xemacs/xemacs-packages/etc/gnus/
%{_datadir}/xemacs/xemacs-packages/etc/gnus/*
%dir %{_datadir}/xemacs/xemacs-packages/etc/guided-tour/
%{_datadir}/xemacs/xemacs-packages/etc/guided-tour/*
%dir %{_datadir}/xemacs/xemacs-packages/etc/haskell-mode/
%doc %{_datadir}/xemacs/xemacs-packages/etc/haskell-mode/fontlock.hs
%doc %{_datadir}/xemacs/xemacs-packages/etc/haskell-mode/indent.hs
%doc %{_datadir}/xemacs/xemacs-packages/etc/haskell-mode/index.html
%doc %{_datadir}/xemacs/xemacs-packages/etc/haskell-mode/installation-guide.html
%dir %{_datadir}/xemacs/xemacs-packages/etc/hm--html-menus/
%dir %{_datadir}/xemacs/xemacs-packages/etc/hm--html-menus/idd/
%{_datadir}/xemacs/xemacs-packages/etc/hm--html-menus/idd/drop
%{_datadir}/xemacs/xemacs-packages/etc/hm--html-menus/idd/dropmsk
%dir %{_datadir}/xemacs/xemacs-packages/etc/hm--html-menus/templates/
%{_datadir}/xemacs/xemacs-packages/etc/hm--html-menus/templates/command-description.html.tmpl
%{_datadir}/xemacs/xemacs-packages/etc/hm--html-menus/templates/frame.html.tmpl
%dir %{_datadir}/xemacs/xemacs-packages/etc/hyperbole/
%doc %{_datadir}/xemacs/xemacs-packages/etc/hyperbole/DEMO
%doc %{_datadir}/xemacs/xemacs-packages/etc/hyperbole/MANIFEST
%doc %{_datadir}/xemacs/xemacs-packages/etc/hyperbole/file-newer
%doc %{_datadir}/xemacs/xemacs-packages/etc/hyperbole/hypb-mouse.txt
%dir %{_datadir}/xemacs/xemacs-packages/etc/hyperbole/kotl/
%doc %{_datadir}/xemacs/xemacs-packages/etc/hyperbole/kotl/EXAMPLE.kotl
%doc %{_datadir}/xemacs/xemacs-packages/etc/hyperbole/kotl/MANIFEST
%doc %{_datadir}/xemacs/xemacs-packages/etc/hyperbole/smart-clib-sym
%dir %{_datadir}/xemacs/xemacs-packages/etc/idlwave/
%{_datadir}/xemacs/xemacs-packages/etc/idlwave/CHANGES
%{_datadir}/xemacs/xemacs-packages/etc/idlwave/idlwave_catalog
%dir %{_datadir}/xemacs/xemacs-packages/etc/ilisp/
%{_datadir}/xemacs/xemacs-packages/etc/ilisp/ilisp-icon.bmp
%{_datadir}/xemacs/xemacs-packages/etc/ilisp/ilisp-icon.ppm
%dir %{_datadir}/xemacs/xemacs-packages/etc/jde/
%dir %{_datadir}/xemacs/xemacs-packages/etc/jde/doc/
%doc %{_datadir}/xemacs/xemacs-packages/etc/jde/doc/*
%dir %{_datadir}/xemacs/xemacs-packages/etc/jde/java/
%{_datadir}/xemacs/xemacs-packages/etc/jde/java/*
%dir %{_datadir}/xemacs/xemacs-packages/etc/jde/plugins/
%{_datadir}/xemacs/xemacs-packages/etc/jde/plugins/*
%dir %{_datadir}/xemacs/xemacs-packages/etc/mew/
%{_datadir}/xemacs/xemacs-packages/etc/mew/*
%dir %{_datadir}/xemacs/xemacs-packages/etc/mine/
%{_datadir}/xemacs/xemacs-packages/etc/mine/*
%dir %{_datadir}/xemacs/xemacs-packages/etc/oo-browser/
%doc %{_datadir}/xemacs/xemacs-packages/etc/oo-browser/BR-COPY
%doc %{_datadir}/xemacs/xemacs-packages/etc/oo-browser/BR-FEATURES
%doc %{_datadir}/xemacs/xemacs-packages/etc/oo-browser/BR-README
%doc %{_datadir}/xemacs/xemacs-packages/etc/oo-browser/BR-RELEASE
%doc %{_datadir}/xemacs/xemacs-packages/etc/oo-browser/BR-VERSION
%doc %{_datadir}/xemacs/xemacs-packages/etc/oo-browser/Make-Env
%dir %{_datadir}/xemacs/xemacs-packages/etc/ps-print/
%{_datadir}/xemacs/xemacs-packages/etc/ps-print/*
%dir %{_datadir}/xemacs/xemacs-packages/etc/psgml/
%{_datadir}/xemacs/xemacs-packages/etc/psgml/*
%dir %{_datadir}/xemacs/xemacs-packages/etc/reftex/
%doc %{_datadir}/xemacs/xemacs-packages/etc/reftex/CHANGES
%doc %{_datadir}/xemacs/xemacs-packages/etc/reftex/NUTSHELL
%dir %{_datadir}/xemacs/xemacs-packages/etc/riece/
%doc %{_datadir}/xemacs/xemacs-packages/etc/riece/*
%dir %{_datadir}/xemacs/xemacs-packages/etc/slider/
%{_datadir}/xemacs/xemacs-packages/etc/slider/*
%dir %{_datadir}/xemacs/xemacs-packages/etc/smilies/
%{_datadir}/xemacs/xemacs-packages/etc/smilies/*
%{_datadir}/xemacs/xemacs-packages/etc/sokoban.levels
%dir %{_datadir}/xemacs/xemacs-packages/etc/sounds/
%{_datadir}/xemacs/xemacs-packages/etc/sounds/*
%{_datadir}/xemacs/xemacs-packages/etc/spook.lines
%dir %{_datadir}/xemacs/xemacs-packages/etc/time/
%{_datadir}/xemacs/xemacs-packages/etc/time/*
%dir %{_datadir}/xemacs/xemacs-packages/etc/text-modes/
%{_datadir}/xemacs/xemacs-packages/etc/text-modes/*.xpm
%{_datadir}/xemacs/xemacs-packages/etc/tpu-edt.xmodmap
%doc %{_datadir}/xemacs/xemacs-packages/etc/viperCard.tex
%dir %{_datadir}/xemacs/xemacs-packages/etc/vm/
%{_datadir}/xemacs/xemacs-packages/etc/vm/*
%dir %{_datadir}/xemacs/xemacs-packages/etc/w3/
%{_datadir}/xemacs/xemacs-packages/etc/w3/*
%dir %{_datadir}/xemacs/xemacs-packages/etc/x-symbol/
%{_datadir}/xemacs/xemacs-packages/etc/x-symbol/*
%dir %{_datadir}/xemacs/xemacs-packages/etc/xslt-process/
%dir %{_datadir}/xemacs/xemacs-packages/etc/xslt-process/java/
%{_datadir}/xemacs/xemacs-packages/etc/xslt-process/java/*
%dir %{_datadir}/xemacs/xemacs-packages/etc/xwem/
%{_datadir}/xemacs/xemacs-packages/etc/xwem/*
%{_datadir}/xemacs/xemacs-packages/etc/yow.lines
%dir %{_datadir}/xemacs/xemacs-packages/etc/zenirc/
%{_datadir}/xemacs/xemacs-packages/etc/zenirc/*
%dir %{_datadir}/xemacs/xemacs-packages/lib-src/
%{_datadir}/xemacs/xemacs-packages/lib-src/*
%dir %{_datadir}/xemacs/xemacs-packages/lisp/
%dir %{_datadir}/xemacs/xemacs-packages/lisp/Sun/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/Sun/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/ada/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/ada/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/apel/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/apel/ChangeLog
%doc %{_datadir}/xemacs/xemacs-packages/lisp/apel/ChangeLog.upstream
%doc %{_datadir}/xemacs/xemacs-packages/lisp/apel/README.en
%doc %{_datadir}/xemacs/xemacs-packages/lisp/apel/README.ja
%dir %{_datadir}/xemacs/xemacs-packages/lisp/auctex/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/auctex/ChangeLog*
%dir %{_datadir}/xemacs/xemacs-packages/lisp/bbdb/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/bbdb/ChangeLog
%doc %{_datadir}/xemacs/xemacs-packages/lisp/bbdb/README
%dir %{_datadir}/xemacs/xemacs-packages/lisp/build/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/build/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/c-support/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/c-support/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/calc/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/calc/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/calendar/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/calendar/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/cc-mode/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/cc-mode/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/cedet-common/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/cedet-common/ChangeLog*
%dir %{_datadir}/xemacs/xemacs-packages/lisp/clearcase/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/clearcase/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/cogre/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/cogre/ChangeLog*
%dir %{_datadir}/xemacs/xemacs-packages/lisp/cookie/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/cookie/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/crisp/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/crisp/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/debug/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/debug/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/dictionary/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/dictionary/ChangeLog
%doc %{_datadir}/xemacs/xemacs-packages/lisp/dictionary/GPL
%doc %{_datadir}/xemacs/xemacs-packages/lisp/dictionary/README
%dir %{_datadir}/xemacs/xemacs-packages/lisp/dired/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/dired/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/docbookide/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/docbookide/ChangeLog
%doc %{_datadir}/xemacs/xemacs-packages/lisp/docbookide/README
%doc %{_datadir}/xemacs/xemacs-packages/lisp/docbookide/dot_emacs
%dir %{_datadir}/xemacs/xemacs-packages/lisp/easypg/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/easypg/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/ecb/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/ecb/ChangeLog
%doc %{_datadir}/xemacs/xemacs-packages/lisp/ecb/README
%doc %{_datadir}/xemacs/xemacs-packages/lisp/ecb/RELEASE_NOTES
%doc %{_datadir}/xemacs/xemacs-packages/lisp/ecb/NEWS
%dir %{_datadir}/xemacs/xemacs-packages/lisp/ecrypto/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/ecrypto/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/ede/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/ede/ChangeLog*
%dir %{_datadir}/xemacs/xemacs-packages/lisp/edebug/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/edebug/ChangeLog
%doc %{_datadir}/xemacs/xemacs-packages/lisp/edebug/README
%dir %{_datadir}/xemacs/xemacs-packages/lisp/ediff/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/ediff/ChangeLog
%doc %{_datadir}/xemacs/xemacs-packages/lisp/ediff/README
%dir %{_datadir}/xemacs/xemacs-packages/lisp/edit-utils/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/edit-utils/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/edt/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/edt/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/efs/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/efs/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/eieio/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/eieio/ChangeLog
%{_datadir}/xemacs/xemacs-packages/lisp/eieio/Project.ede
%dir %{_datadir}/xemacs/xemacs-packages/lisp/elib/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/elib/ChangeLog
%doc %{_datadir}/xemacs/xemacs-packages/lisp/elib/NEWS
%doc %{_datadir}/xemacs/xemacs-packages/lisp/elib/README
%dir %{_datadir}/xemacs/xemacs-packages/lisp/emerge/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/emerge/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/erc/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/erc/ChangeLog*
%doc %{_datadir}/xemacs/xemacs-packages/lisp/erc/Makefile*
%doc %{_datadir}/xemacs/xemacs-packages/lisp/erc/HACKING.upstream
%doc %{_datadir}/xemacs/xemacs-packages/lisp/erc/FOR-RELEASE.upstream
%dir %{_datadir}/xemacs/xemacs-packages/lisp/escreen/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/escreen/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/eshell/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/eshell/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/eterm/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/eterm/ChangeLog
%doc %{_datadir}/xemacs/xemacs-packages/lisp/eterm/QUESTIONS
%doc %{_datadir}/xemacs/xemacs-packages/lisp/eterm/README.term
%doc %{_datadir}/xemacs/xemacs-packages/lisp/eterm/TODO.term
%dir %{_datadir}/xemacs/xemacs-packages/lisp/eudc/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/eudc/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/footnote/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/footnote/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/forms/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/forms/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/fortran-modes/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/fortran-modes/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/frame-icon/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/frame-icon/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/fsf-compat/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/fsf-compat/ChangeLog
%doc %{_datadir}/xemacs/xemacs-packages/lisp/fsf-compat/README
%dir %{_datadir}/xemacs/xemacs-packages/lisp/games/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/games/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/general-docs/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/general-docs/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/gnats/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/gnats/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/gnus/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/gnus/ChangeLog
%doc %{_datadir}/xemacs/xemacs-packages/lisp/gnus/ChangeLog.1.upstream
%doc %{_datadir}/xemacs/xemacs-packages/lisp/gnus/ChangeLog.2.upstream
%doc %{_datadir}/xemacs/xemacs-packages/lisp/gnus/ChangeLog.upstream
%doc %{_datadir}/xemacs/xemacs-packages/lisp/gnus/ChangeLog.contrib.upstream
%doc %{_datadir}/xemacs/xemacs-packages/lisp/gnus/GNUS-NEWS
%doc %{_datadir}/xemacs/xemacs-packages/lisp/gnus/COPYING
%doc %{_datadir}/xemacs/xemacs-packages/lisp/gnus/smiley.el.upstream
%dir %{_datadir}/xemacs/xemacs-packages/lisp/guided-tour/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/guided-tour/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/haskell-mode/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/haskell-mode/ChangeLog
%doc %{_datadir}/xemacs/xemacs-packages/lisp/haskell-mode/ChangeLog.upstream
%doc %{_datadir}/xemacs/xemacs-packages/lisp/haskell-mode/Makefile.upstream
%doc %{_datadir}/xemacs/xemacs-packages/lisp/haskell-mode/NEWS
%dir %{_datadir}/xemacs/xemacs-packages/lisp/hm--html-menus/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/hm--html-menus/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/hyperbole/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/hyperbole/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/hyperbole/kotl/
%{_datadir}/xemacs/xemacs-packages/lisp/hyperbole/h-skip-bytec.lsp
%dir %{_datadir}/xemacs/xemacs-packages/lisp/ibuffer/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/ibuffer/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/idlwave/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/idlwave/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/igrep/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/igrep/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/ilisp/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/ilisp/COPYING
%doc %{_datadir}/xemacs/xemacs-packages/lisp/ilisp/ChangeLog
%doc %{_datadir}/xemacs/xemacs-packages/lisp/ilisp/GETTING-ILISP
%doc %{_datadir}/xemacs/xemacs-packages/lisp/ilisp/HISTORY
%doc %{_datadir}/xemacs/xemacs-packages/lisp/ilisp/INSTALLATION
%doc %{_datadir}/xemacs/xemacs-packages/lisp/ilisp/Makefile
%doc %{_datadir}/xemacs/xemacs-packages/lisp/ilisp/README
%doc %{_datadir}/xemacs/xemacs-packages/lisp/ilisp/comint-v18.el.upstream
%{_datadir}/xemacs/xemacs-packages/lisp/ilisp/Welcome
%{_datadir}/xemacs/xemacs-packages/lisp/ilisp/allegro.lisp
%{_datadir}/xemacs/xemacs-packages/lisp/ilisp/cl-chs-init.lisp
%{_datadir}/xemacs/xemacs-packages/lisp/ilisp/cl-ilisp.lisp
%{_datadir}/xemacs/xemacs-packages/lisp/ilisp/cmulisp.lisp
%{_datadir}/xemacs/xemacs-packages/lisp/ilisp/cormanlisp.lisp
%dir %{_datadir}/xemacs/xemacs-packages/lisp/ilisp/extra/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/ilisp/extra/README
%{_datadir}/xemacs/xemacs-packages/lisp/ilisp/guile-ilisp.scm
%{_datadir}/xemacs/xemacs-packages/lisp/ilisp/ilisp-pkg.lisp
%{_datadir}/xemacs/xemacs-packages/lisp/ilisp/ilisp.emacs
%{_datadir}/xemacs/xemacs-packages/lisp/ilisp/lispworks.lisp
%{_datadir}/xemacs/xemacs-packages/lisp/ilisp/lucid.lisp
%{_datadir}/xemacs/xemacs-packages/lisp/ilisp/mzscheme-ilisp.scm
%{_datadir}/xemacs/xemacs-packages/lisp/ilisp/openmcl.lisp
%{_datadir}/xemacs/xemacs-packages/lisp/ilisp/sbcl.lisp
%{_datadir}/xemacs/xemacs-packages/lisp/ilisp/sblisp.lisp
%dir %{_datadir}/xemacs/xemacs-packages/lisp/ispell/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/ispell/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/jde/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/jde/ChangeLog
%doc %{_datadir}/xemacs/xemacs-packages/lisp/jde/ChangeLog.upstream
%dir %{_datadir}/xemacs/xemacs-packages/lisp/mail-lib/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/mail-lib/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/mailcrypt/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/mailcrypt/ANNOUNCE
%doc %{_datadir}/xemacs/xemacs-packages/lisp/mailcrypt/ChangeLog
%doc %{_datadir}/xemacs/xemacs-packages/lisp/mailcrypt/ChangeLog.1
%{_datadir}/xemacs/xemacs-packages/lisp/mailcrypt/LCD-entry
%doc %{_datadir}/xemacs/xemacs-packages/lisp/mailcrypt/NEWS
%doc %{_datadir}/xemacs/xemacs-packages/lisp/mailcrypt/ONEWS
%doc %{_datadir}/xemacs/xemacs-packages/lisp/mailcrypt/README*
%doc %{_datadir}/xemacs/xemacs-packages/lisp/mailcrypt/WARNINGS
%dir %{_datadir}/xemacs/xemacs-packages/lisp/mew/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/mew/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/mh-e/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/mh-e/COPYING
%doc %{_datadir}/xemacs/xemacs-packages/lisp/mh-e/ChangeLog*
%doc %{_datadir}/xemacs/xemacs-packages/lisp/mh-e/*NEWS*
%doc %{_datadir}/xemacs/xemacs-packages/lisp/mh-e/README*
%dir %{_datadir}/xemacs/xemacs-packages/lisp/mine/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/mine/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/misc-games/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/misc-games/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/mmm-mode/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/mmm-mode/AUTHORS
%doc %{_datadir}/xemacs/xemacs-packages/lisp/mmm-mode/ChangeLog
%doc %{_datadir}/xemacs/xemacs-packages/lisp/mmm-mode/COPYING
%doc %{_datadir}/xemacs/xemacs-packages/lisp/mmm-mode/FAQ
%doc %{_datadir}/xemacs/xemacs-packages/lisp/mmm-mode/NEWS
%doc %{_datadir}/xemacs/xemacs-packages/lisp/mmm-mode/README
%doc %{_datadir}/xemacs/xemacs-packages/lisp/mmm-mode/README.Mason
%doc %{_datadir}/xemacs/xemacs-packages/lisp/mmm-mode/TODO
%dir %{_datadir}/xemacs/xemacs-packages/lisp/net-utils/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/net-utils/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/ocaml/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/ocaml/ChangeLog*
%doc %{_datadir}/xemacs/xemacs-packages/lisp/ocaml/README*
%dir %{_datadir}/xemacs/xemacs-packages/lisp/oo-browser/
%{_datadir}/xemacs/xemacs-packages/lisp/oo-browser/br-c-tags
%{_datadir}/xemacs/xemacs-packages/lisp/oo-browser/br-help
%{_datadir}/xemacs/xemacs-packages/lisp/oo-browser/br-help-ms
%doc %{_datadir}/xemacs/xemacs-packages/lisp/oo-browser/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/os-utils/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/os-utils/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/pc/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/pc/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/pcl-cvs/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/pcl-cvs/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/pcomplete/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/pcomplete/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/perl-modes/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/perl-modes/ChangeLog*
%dir %{_datadir}/xemacs/xemacs-packages/lisp/pgg/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/pgg/ChangeLog*
%doc %{_datadir}/xemacs/xemacs-packages/lisp/pgg/README*
%dir %{_datadir}/xemacs/xemacs-packages/lisp/prog-modes/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/prog-modes/ChangeLog*
%dir %{_datadir}/xemacs/xemacs-packages/lisp/ps-print/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/ps-print/ChangeLog
%doc %{_datadir}/xemacs/xemacs-packages/lisp/ps-print/README
%doc %{_datadir}/xemacs/xemacs-packages/lisp/ps-print/ps-print-20.new
%doc %{_datadir}/xemacs/xemacs-packages/lisp/ps-print/ps-print-21.new
%dir %{_datadir}/xemacs/xemacs-packages/lisp/psgml-dtds/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/psgml-dtds/ChangeLog*
%dir %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/CATALOG
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/ECAT
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/HTML3.2.decl
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/HTML4.01.decl
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/HTML4.decl
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/HTMLlat1.ent
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/HTMLspecial.ent
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/HTMLsymbol.ent
%dir %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/ISO_8879-1986/
%dir %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/ISO_8879-1986/entities/
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/ISO_8879-1986/entities/Added_Latin_1
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/ISO_8879-1986/entities/Added_Latin_1_for_HTML
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/ISO_8879-1986/entities/Added_Math_Symbols-_Delimiters
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/ISO_8879-1986/entities/Added_Math_Symbols-_Ordinary
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/ISO_8879-1986/entities/Added_Math_Symbols-_Relations
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/ISO_8879-1986/entities/Diacritical_Marks
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/ISO_8879-1986/entities/General_Technical
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/ISO_8879-1986/entities/Greek_Symbols
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/ISO_8879-1986/entities/ISOamsa
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/ISO_8879-1986/entities/ISOamsb
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/ISO_8879-1986/entities/ISOamsc
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/ISO_8879-1986/entities/ISOamsn
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/ISO_8879-1986/entities/ISOamso
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/ISO_8879-1986/entities/ISOamsr
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/ISO_8879-1986/entities/ISObox
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/ISO_8879-1986/entities/ISOcyr1
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/ISO_8879-1986/entities/ISOcyr2
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/ISO_8879-1986/entities/ISOdia
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/ISO_8879-1986/entities/ISOgrk1
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/ISO_8879-1986/entities/ISOgrk2
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/ISO_8879-1986/entities/ISOgrk3
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/ISO_8879-1986/entities/ISOgrk4
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/ISO_8879-1986/entities/ISOlat1
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/ISO_8879-1986/entities/ISOlat2
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/ISO_8879-1986/entities/ISOnum
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/ISO_8879-1986/entities/ISOpub
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/ISO_8879-1986/entities/ISOtech
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/ISO_8879-1986/entities/Numeric_and_Special_Graphic
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/ISO_8879-1986/entities/isoamsa.ent
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/ISO_8879-1986/entities/isoamsb.ent
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/ISO_8879-1986/entities/isoamsc.ent
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/ISO_8879-1986/entities/isoamsn.ent
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/ISO_8879-1986/entities/isoamso.ent
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/ISO_8879-1986/entities/isoamsr.ent
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/ISO_8879-1986/entities/isobox.ent
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/ISO_8879-1986/entities/isocyr1.ent
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/ISO_8879-1986/entities/isocyr2.ent
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/ISO_8879-1986/entities/isodia.ent
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/ISO_8879-1986/entities/isogrk3.ent
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/ISO_8879-1986/entities/isolat1.ent
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/ISO_8879-1986/entities/isolat2.ent
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/ISO_8879-1986/entities/isomfrk.ent
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/ISO_8879-1986/entities/isomopf.ent
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/ISO_8879-1986/entities/isomscr.ent
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/ISO_8879-1986/entities/isonum.ent
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/ISO_8879-1986/entities/isopub.ent
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/ISO_8879-1986/entities/isotech.ent
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/ISOlat1.ent
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/README.cdtd
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/cals-tbl.dtd
%dir %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/cdtd/
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/cdtd/docbook
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/cdtd/html
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/cdtd/html-3
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/cdtd/html-3-r
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/cdtd/html-3.2
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/cdtd/html-4.01frame
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/cdtd/html-4.01s
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/cdtd/html-4frame
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/cdtd/html-4s
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/cdtd/html-r
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/cdtd/mathml
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/cdtd/xhtml1-frameset
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/cdtd/xhtml1-strict
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/cdtd/xhtml1-transitional
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/datatypes.dtd
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/dbcent.mod
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/dbgenent.mod
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/dbhier.mod
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/dbnotn.mod
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/dbpool.mod
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/docbook.dcl
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/docbook.dtd
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/html-3.2.dtd
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/html-3.dtd
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/html-3s.dtd
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/html-4.01frame.dtd
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/html-4.01l.dtd
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/html-4.01s.dtd
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/html-4frame.dtd
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/html-4l.dtd
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/html-4s.dtd
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/html-icons.sgml
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/html-latin.sgml
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/html-math.sgml
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/html-s.dtd
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/html.decl
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/html.dtd
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/mathml.dtd
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/mmlalias.ent
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/mmlextra.ent
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/structures.dtd
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/versionInfo.ent
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/xhtml-lat1.ent
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/xhtml-special.ent
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/xhtml-symbol.ent
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/xhtml1-frameset.dtd
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/xhtml1-strict.dtd
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/xhtml1-transitional-mathml.dtd
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/xhtml1-transitional.dtd
%doc %{_datadir}/xemacs/xemacs-packages/etc/psgml-dtds/xhtml1.dcl
%dir %{_datadir}/xemacs/xemacs-packages/etc/python-modes/
%doc %{_datadir}/xemacs/xemacs-packages/etc/python-modes/pydoc_lisp.py
%dir %{_datadir}/xemacs/xemacs-packages/lisp/psgml/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/psgml/ChangeLog*
%dir %{_datadir}/xemacs/xemacs-packages/lisp/python-modes/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/python-modes/ChangeLog*
%doc %{_datadir}/xemacs/xemacs-packages/lisp/python-modes/pydoc-el-README
%dir %{_datadir}/xemacs/xemacs-packages/lisp/re-builder/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/re-builder/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/reftex/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/reftex/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/riece/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/riece/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/rmail/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/rmail/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/ruby-modes/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/ruby-modes/ChangeLog*
%doc %{_datadir}/xemacs/xemacs-packages/lisp/ruby-modes/README*
%dir %{_datadir}/xemacs/xemacs-packages/lisp/sasl/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/sasl/ChangeLog
%doc %{_datadir}/xemacs/xemacs-packages/lisp/sasl/README
%dir %{_datadir}/xemacs/xemacs-packages/lisp/scheme/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/scheme/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/semantic/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/semantic/ChangeLog*
%doc %{_datadir}/xemacs/xemacs-packages/lisp/semantic/NEWS*
%{_datadir}/xemacs/xemacs-packages/lisp/semantic/*.ede
%{_datadir}/xemacs/xemacs-packages/lisp/semantic/*.bnf
%dir %{_datadir}/xemacs/xemacs-packages/lisp/sgml/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/sgml/ChangeLog*
%dir %{_datadir}/xemacs/xemacs-packages/lisp/sh-script/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/sh-script/ChangeLog*
%dir %{_datadir}/xemacs/xemacs-packages/lisp/sieve/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/sieve/ChangeLog*
%dir %{_datadir}/xemacs/xemacs-packages/lisp/slider/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/slider/ChangeLog*
%dir %{_datadir}/xemacs/xemacs-packages/lisp/sml-mode/
%{_datadir}/xemacs/xemacs-packages/lisp/sml-mode/BUGS
%{_datadir}/xemacs/xemacs-packages/lisp/sml-mode/ChangeLog*
%{_datadir}/xemacs/xemacs-packages/lisp/sml-mode/NEWS*
%{_datadir}/xemacs/xemacs-packages/lisp/sml-mode/README*
%{_datadir}/xemacs/xemacs-packages/lisp/sml-mode/TODO*
%{_datadir}/xemacs/xemacs-packages/lisp/sml-mode/sml-mode.spec
%{_datadir}/xemacs/xemacs-packages/lisp/sml-mode/testcases.sml
%dir %{_datadir}/xemacs/xemacs-packages/lisp/sounds-au/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/sounds-au/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/sounds-wav/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/sounds-wav/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/speedbar/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/speedbar/ChangeLog
%{_datadir}/xemacs/xemacs-packages/lisp/speedbar/*.xpm
%dir %{_datadir}/xemacs/xemacs-packages/lisp/strokes/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/strokes/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/supercite/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/supercite/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/texinfo/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/texinfo/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/text-modes/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/text-modes/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/textools/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/textools/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/time/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/time/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/tm/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/tm/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/tooltalk/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/tooltalk/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/tpu/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/tpu/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/tramp/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/tramp/ChangeLog
%doc %{_datadir}/xemacs/xemacs-packages/lisp/tramp/ChangeLog.upstream
%dir %{_datadir}/xemacs/xemacs-packages/lisp/vc-cc/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/vc-cc/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/vc/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/vc/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/vhdl/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/vhdl/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/view-process/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/view-process/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/viper/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/viper/ChangeLog
%doc %{_datadir}/xemacs/xemacs-packages/lisp/viper/README
%dir %{_datadir}/xemacs/xemacs-packages/lisp/vm/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/vm/ChangeLog
%doc %{_datadir}/xemacs/xemacs-packages/lisp/vm/NEWS
%dir %{_datadir}/xemacs/xemacs-packages/lisp/w3/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/w3/BUGS
%doc %{_datadir}/xemacs/xemacs-packages/lisp/w3/ChangeLog
%doc %{_datadir}/xemacs/xemacs-packages/lisp/w3/HOWTO
%doc %{_datadir}/xemacs/xemacs-packages/lisp/w3/README
%doc %{_datadir}/xemacs/xemacs-packages/lisp/w3/TODO
%doc %{_datadir}/xemacs/xemacs-packages/lisp/w3/md5.el.upstream
%dir %{_datadir}/xemacs/xemacs-packages/lisp/x-symbol/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/x-symbol/ChangeLog
%doc %{_datadir}/xemacs/xemacs-packages/lisp/x-symbol/ChangeLog.2.upstream
%doc %{_datadir}/xemacs/xemacs-packages/lisp/x-symbol/ChangeLog.3.upstream
%doc %{_datadir}/xemacs/xemacs-packages/lisp/x-symbol/ChangeLog.upstream
%doc %{_datadir}/xemacs/xemacs-packages/lisp/x-symbol/Makefile.upstream
%doc %{_datadir}/xemacs/xemacs-packages/lisp/x-symbol/README
%dir %{_datadir}/xemacs/xemacs-packages/lisp/xemacs-base/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/xemacs-base/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/xemacs-devel/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/xemacs-devel/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/xetla/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/xetla/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/xlib/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/xlib/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/xslide/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/xslide/ChangeLog
%doc %{_datadir}/xemacs/xemacs-packages/lisp/xslide/ChangeLog.upstream
%doc %{_datadir}/xemacs/xemacs-packages/lisp/xslide/Makefile.upstream
%doc %{_datadir}/xemacs/xemacs-packages/lisp/xslide/README.TXT
%doc %{_datadir}/xemacs/xemacs-packages/lisp/xslide/dot_emacs
%{_datadir}/xemacs/xemacs-packages/lisp/xslide/xslide-initial.xsl
%doc %{_datadir}/xemacs/xemacs-packages/lisp/xslide/NEWS
%doc %{_datadir}/xemacs/xemacs-packages/lisp/xslide/TODO
%dir %{_datadir}/xemacs/xemacs-packages/lisp/xslt-process/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/xslt-process/ChangeLog
%doc %{_datadir}/xemacs/xemacs-packages/lisp/xslt-process/README
%dir %{_datadir}/xemacs/xemacs-packages/lisp/xwem/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/xwem/ChangeLog
%dir %{_datadir}/xemacs/xemacs-packages/lisp/zenirc/
%doc %{_datadir}/xemacs/xemacs-packages/lisp/zenirc/BUGS
%doc %{_datadir}/xemacs/xemacs-packages/lisp/zenirc/ChangeLog
%doc %{_datadir}/xemacs/xemacs-packages/lisp/zenirc/NEWS
%doc %{_datadir}/xemacs/xemacs-packages/lisp/zenirc/README
%doc %{_datadir}/xemacs/xemacs-packages/lisp/zenirc/TODO
%dir %{_datadir}/xemacs/xemacs-packages/man/
%doc %{_datadir}/xemacs/xemacs-packages/man/*
%dir %{_datadir}/xemacs/xemacs-packages/pkginfo/
%{_datadir}/xemacs/xemacs-packages/pkginfo/*

%files       -n xemacs-packages-info
%defattr(-,root,root)
%dir %{_datadir}/xemacs/mule-packages/info/
%doc %{_datadir}/xemacs/mule-packages/info/*
%dir %{_datadir}/xemacs/xemacs-packages/info/
%doc %{_datadir}/xemacs/xemacs-packages/info/*

%files       -n xemacs-packages-el -f xe-list-el-with-elc
%defattr(-,root,root)

%changelog
* Tue Jul  9 2024 Ana Guerrero <ana.guerrero@suse.com>
- Drop dependency on fwnndev, fwnn is dead and unmaintained.
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Fri Oct 20 2023 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch to drop build date (boo#1047218)
* Thu Aug 18 2022 Dr. Werner Fink <werner@suse.de>
- tramp.texi: Try to avoid old macros nor know by modern texinfo
* Thu Aug 18 2022 Dr. Werner Fink <werner@suse.de>
- Drop canna support: canna has not been maintained for a long time
  and sec issues are not being addressed (bsc#1199280).
* Mon Feb  7 2022 Dr. Werner Fink <werner@suse.de>
- Require glibc-locale at build time as otherwise iconv fails
* Tue Aug 18 2020 Dr. Werner Fink <werner@suse.de>
- Add par and info to requirement at build time
* Mon Jul  3 2017 bwiedemann@suse.com
- Use gzip -n to not add timestamps to .gz headers
- Use fdupes -o name to always create symlinks in the same direction
* Fri Nov 27 2015 werner@suse.de
- Change encoding order in application defaults of xemacs and
  xemacs-packages to avoid breakdown of FontSet scheme of libX11
  at startup (bsc#952361)
* Thu Feb 26 2015 werner@suse.de
- Make makeinfo less pettifogging
* Wed Feb 11 2015 werner@suse.de
- Add patch xemacs-packages-20130822-tramp.patch
  to fix problem of not loaded subr-more (boo#857207)
* Fri Aug 23 2013 ailin.nemui@gmail.com
- update packages to latest xemacs versions:
  * leim/quail warns about duplicate rules
  * cc-mode 1.64 -> 1.69 (5.32.5): see individual ChangeLog
  * edit-utils 2.50 -> 2.51: import find-lisp
  * efs 1.34 -> 1.35: texinfo fix in docs...
  * erc: fixes in log-file handling
  * hyperbole 1.18 -> 1.19 (no source change)
  * misc-games: fix name clash in doctor
  * prog-modes 2.28 -> 2.29: go mode updated to 16503
  * xemacs-base 2.35 -> 2.36: rcfiles added, subr-more learns
    number-sequence, string-or-null-p, booleanp
* Tue Apr  2 2013 ailin.nemui@gmail.com
- update packages to latest xemacs versions:
  * xemacs-base 2.32 -> 2.35: new core subr-more, new file-util
    from GNU Emacs
  * tramp 1.41 -> 1.45 (2.2.7): latest bugfixes, new gvfs backend
  * scheme 1.18 -> 1.19: fix imenu-syntax-alist
  * os-utils 1.41 -> 1.42: archive-mode also provide arc-mode for
    GNU compat
  * edit-utils 2.49 -> 2.50: added ido mode, which-func from GNU
  * cc-mode 1.60 -> 1.64: small fixes, check
    http://cc-mode.sourceforge.net for detailed changelog
* Wed Jan 30 2013 ailin.nemui@gmail.com
- update packages to latest xemacs versions:
  * cc-mode 1.57 -> 1.60: small fixes, check
    http://cc-mode.sourceforge.net for detailed changelog
  * edit-utils 2.47 -> 2.49: add list-register
  * prog-modes 2.27 -> 2.28: update go-mode to 14989
  * tramp 1.40 (2.0.56) -> 1.41 (2.2.7-pre): major update,
    details see ChangeLog.upstream
  * ediff 1.81 -> 1.82, pcl-cvs 1.70 -> 1.71:
  fix tramp compilation
* Mon Nov 19 2012 ailin.nemui@gmail.com
- update packages to latest xemacs versions:
  * edit-utils 2.46 -> 2.47: support behavior in user-colors
* Tue Oct  2 2012 ailin.nemui@gmail.com
- update packages to latest xemacs versions:
  * prog-modes 2.26 -> 2.27: go-mode update to 13677 (handle unit
    test failure)
  * cc-mode 1.55 -> 1.57: bug fixes
* Tue Sep 18 2012 werner@suse.de
- Again, make it build with latest TeXLive 2012
* Wed Aug  8 2012 ailin.nemui@gmail.com
- update packages to latest xemacs versions:
  * auctex 1.49 -> 1.51 (11.84), details see doc/changes.texi
  * cc-mode 1.51 -> 1.55 (5.32.2),
    see http://cc-mode.sourceforge.net/changes-532.php
  * gnus 1.94 -> 1.95 (5.10.10),
    see http://gnus.org/manual/gnus_363.html#SEC366
  * leim 1.32 -> 1.33, prog-modes 2.25 -> 2.26,
    ruby-modes 1.04 -> 1.05 (1.8.7), w3 1.36 -> 1.38 (4.0pre47),
    xemacs-base 2.31 -> 2.32,
    for changes see the various ChangeLog files in the package
- fix packaging bug that stop cperl-mode 6.2 from opening
- upstream license change to GPLv3+
- add patch for missing CVS keywords in hg checkout
- add patch to update hg checkout of gnus to match release version
* Mon Jul 23 2012 werner@suse.de
- Make it build with latest TeXLive 2012
* Sat Jun 30 2012 i@marguerite.su
- fix 12.2 builds.
  * bdftopcf is now a separated package from xorg-x11.
  * mkfontdir is now a separated package from xorg-x11-utils-devel.
- fix sle builds.
* Thu Mar 22 2012 werner@suse.de
- Make rpmlint happy
* Fri Mar  2 2012 werner@suse.de
- Update to sumo-2012-02-14
  * as there are a lot of changes you may read
    https://bitbucket.org/xemacs/xemacs-packages/changesets
* Sat May 15 2010 coolo@novell.com
- ignore subpackages required by xemacs to avoid build cycle
* Wed Mar 31 2010 werner@suse.de
- Force build with newer test version instead of 25.5.29 (bnc#590429)
* Mon Feb 22 2010 werner@suse.de
- Update the sub package vc to 1.48 to fix a bug (bnc#568556)
* Wed Dec  9 2009 werner@suse.de
- Fix the fix in the spec file to make semantic/auto-autoloads.el
  work again (bnc#557739)
* Mon Dec  7 2009 werner@suse.de
- Make it work with latest xemacs beta version
* Wed Dec  2 2009 werner@suse.de
- Add missing autoloads to fix nasty error message (bnc#557739)
* Wed Aug 26 2009 tiwai@suse.de
- Add provides and obsoletes for apel-xemacs
* Tue Aug 25 2009 aj@suse.de
- Apply patch for apel to make it build.
- Fix filelist.
- Fix some rpmlint warnings.
* Mon Jun 22 2009 coolo@novell.com
- update to sumo-2009-02-17.
  * way too many changes to list them all, see
    http://xemacs.org/Releases/2009-02-17.html
* Tue May 13 2008 mfabian@suse.de
- bnc#389154: add fix for fast-lock to avoid the possible
  execution of arbitrary lisp code.
* Fri Dec 21 2007 mfabian@suse.de
- fix wrong property list entries for faces.
* Wed Dec  5 2007 mfabian@suse.de
- remove openldap2 from BuildRequires.
* Fri Aug 10 2007 mfabian@suse.de
- update German app-defaults.
* Wed Aug  8 2007 mfabian@suse.de
- add mule-lisp-directory to load-path in package-compile.el
- add fix-build-failure-in-mule-ucs.patch by Aidan Kehoe to fix
  build failure im mule-ucs with xemacs-21.5.28.20070807.
  (see http://mid.gmane.org/18106.11226.538195.43364@parhasard.net).
* Mon Jul 16 2007 mfabian@suse.de
- update to sumo-2007-04-27.
  • remove bugzilla-129874-do-not-output-useless-error-messages-when-using-cvs-status.patch
  (included upstream).
  • remove bugzilla-219217-w3-does-not-display-anything.patch
    (not needed anymore because newer font.el is now in
    xemacs core).
- make it build again in the build service for openSUSE < 10.2.
* Mon Apr 30 2007 ro@suse.de
- added unzip to buildrequires
* Fri Apr 20 2007 aj@suse.de
- Use texlive for building.
* Mon Nov 20 2006 mfabian@suse.de
- Bugzilla #219217: "XEmacs W3 Doesn't display anything"
* Thu Aug 31 2006 mfabian@suse.de
- add "chmod 755 $RPM_SOURCE_DIR/texi2utf8" to make
  it build in the openSUSE build service.
  Permissions for any file in $RPM_SOURCE_DIR are nowhere guaranteed
  to be preserved.
* Mon Jul  3 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jun 30 2006 mfabian@suse.de
- Bugzilla #183805: add missing autoloads to make the menu
  "Options -> Advanced (Customize) -> Emacs" work without having
  xemacs-el and xemacs-packages-el installed.
* Wed Jun 28 2006 mfabian@suse.de
- update to sumo-2006-05-10
  + remove bugzilla-142822-riece.patch (included upstream).
  + remove bugzilla-130379-do-not-autoload-edmacro.patch (included
    upstream).
- Bugzilla #129874: don't output useless error messages when
  using 'M-x cvs-status'.
* Thu Mar 30 2006 mfabian@suse.de
- Bugzilla #130379: do not autoload edmacro from xwem autoloads.
* Tue Mar 21 2006 mfabian@suse.de
- Bugzilla #130200: "ediff won't work": The auto-autoloads.el files
  have to be generated differently when XEmacs 21.5.x is used to
  build the packages.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan 12 2006 mfabian@suse.de
- Bugzilla #142822: make riece work again.
* Fri Dec 30 2005 mfabian@suse.de
- fix file list to make it build.
* Fri Dec 16 2005 mfabian@suse.de
- bugzilla #139625: add vm-charset-unknown-problem.patch.
* Mon Dec 12 2005 mfabian@suse.de
- update to sumo-2005-12-08.
- adapt apel patch
- adapt diff mode patch (see Bugzilla #32035 (#suse17035)).
- remove  packages-cvs-xemacs-sumo-2005-07-15-bugzilla-106703-flyspell-slow.patch(included upstream)
- liece and ess have been remove upstream, remove from file list.
* Tue Aug 23 2005 mfabian@suse.de
- Bugzilla #106703: flyspell-mode in XEmacs became increadibly slow
* Wed Jul 20 2005 mfabian@suse.de
- update to sumo-2005-07-15.
* Fri May 13 2005 mfabian@suse.de
- update to sumo-2005-05-05.
* Mon Feb 14 2005 mfabian@suse.de
- format info files with makeinfo instead of with XEmacs to
  get correct UTF-8 output.
- fix wrong references in tm-ja.texi.
* Tue Feb  8 2005 mfabian@suse.de
- improve last patch according to trigger autoload of
  "whitespace.el" by 'whitespace-global-mode'.
  (suggestion by Ville Skyttä <scop@xemacs.org> to autoload).
* Mon Feb  7 2005 mfabian@suse.de
- the call to 'define-minor-mode' in whitespace.el had an
  [#]##autoload cookie, which was wrong.
* Thu Jan 27 2005 mfabian@suse.de
- update to sumo-2005-01-18.
- disable build of skk, we have a newer version of skk in
  an extra package "ddskk-xemacs" now.
- disable build of lookup, I'll add a new package "lookup-xemacs"
  which will contain a newer version of lookup.
- convert all texinfo files to UTF-8 to get the .info files
  created in UTF-8 encoding.
* Tue Jan  4 2005 mfabian@suse.de
- use "BuildArch:    noarch" to save space on the DVD.
* Thu Dec 23 2004 mfabian@suse.de
- update to to sumo-2004-08-18.
* Mon Dec 13 2004 mfabian@suse.de
- the XLC_LOCALE files were changed upstream in X11 (iso8859-1
  now always comes first, even in en_US.UTF-8). Fix the Japanese
  app-defaults for XEmacs so that the menus display correctly
  with both the old and the new XLC_LOCALE file.
* Mon Oct  4 2004 werner@suse.de
- Avoid uninitalized cc-mode clones which cause crash on x86_64
  (bug #46742)
* Mon Mar 22 2004 mfabian@suse.de
- Bugzilla #36720: use -adobe-helvetica-bold-* as the default
  font for the menus for de,ro,fr instead of -gnu-unifont-
  because most users like it better. For Japanese, add
  efont-biwidth as the default menu font for Unicode and leave
  second in the list gnu-unicode as a fallback.
* Sat Mar 13 2004 mfabian@suse.de
- Bugzilla #35871: remove nonsense dependency on zsh.
* Fri Feb 20 2004 mfabian@suse.de
- revert last change because the build failed. These removed files
  are some sort of documentation and might be useful.
* Mon Feb 16 2004 kukuk@suse.de
- Remove helper scripts from install list
* Fri Feb 13 2004 mfabian@suse.de
- update to sumo-2004-02-02.
- disable build of hyperbole and oo-browser because XEmacs
  crashes when building these.
* Mon Nov  3 2003 ro@suse.de
- updated neededforbuild
- don't build as root
* Sat Aug 23 2003 mfabian@suse.de
- use utf-8 as the default encoding for EDICT dictionaries.
* Fri Aug 22 2003 mfabian@suse.de
- update to sumo-2003-06-29.
- add tetex te_kpath to needeforbuild.
- remove obsolete patches and adapt some others.
- add hack to install latin-unity-tables.el.
* Fri Aug 22 2003 mfabian@suse.de
- fix "Provides:"
* Wed Aug 20 2003 mfabian@suse.de
- split new packages out of xemacs{,-el,-info}:
  xemacs-packages{,-el,-info}
- use buildroot for building the XEmacs packages
* Sat Aug 16 2003 adrian@suse.de
- install desktop file from kappfinder
* Fri Jul 25 2003 mfabian@suse.de
- fix race condition when generating the file list.
* Tue Jun 24 2003 ro@suse.de
- added directories to filelist
* Mon Jun 23 2003 ro@suse.de
- fixed filelist
* Thu Mar 13 2003 mfabian@suse.de
- Bug #25300: call 'latin-unity-install' for non-UTF-8 locales in
  site-packages/lisp/term/func-keys.el to write files in
  iso-8859-15 encoding correctly without inserting
  ISO-2022 escape sequences. Don't call it in UTF-8 locales!
  If 'latin-unity-install' is called in a UTF-8 locale,
  the behaviour of the coding systems "binary" and "no-conversion"
  becomes strange, they convert to UTF-8 when writing files
  with German umlauts, which is surprising for "binary".
* Thu Mar  6 2003 kukuk@suse.de
- Remove cyrus-sasl from neededforbuild
* Fri Feb 28 2003 mfabian@suse.de
- fix Bugzilla #23472:
  generate /usr/share/xemacs/xemacs-packages/info/dir and
  /usr/share/xemacs/mule-packages/info/dir and include them
  in the xemacs-info package.
* Thu Feb 27 2003 mfabian@suse.de
- include latest changes by Ben <ben@xemacs.org> to edebug
  to make it work again. The edebug as included in
  sumo-2003-02-05 doesn't work at all.
- improve Werner's func-keys.el
  (make XIM work right ja_JP.UTF-8 locale, load latin-unity
  and latin-euro-input, append the coding-system setup stuff to
  'before-init-hook instead of adding it at the beginning because
  'mule-init is already in 'before-init-hook)
* Wed Feb 26 2003 werner@suse.de
- Fix coding system settings: use the correct value
* Fri Feb 14 2003 schwab@suse.de
- Fix data limit check.
* Thu Feb  6 2003 mfabian@suse.de
- update packages to sumo-2003-02-05
  (fixes the problem that XEmacs didn't automatically switch
  to c++-mode, perl-mode, etc. anymore. The initial values of
  interpreter-mode-alist and auto-mode-alist are rather short
  now and are dynamically changed when a package is loaded. To
  make this work a sufficiently uptodate Sumo was necessary).
- disable packages-cvs-sumo-2002-09-19-comint.patch again, XEmacs
  shell-mode works better with TERM=emacs and Werner added the
  emacs entry to terminfo again.
- remove hunks which are included upstream from
  packages-cvs-xemacs-sumo-2002-05-22-locale-start.patch
  packages-cvs-sumo-2002-09-19-xslt-process.patch
* Thu Jan 30 2003 mfabian@suse.de
- update to 21.4.12
- add packages-cvs-sumo-2002-09-19-comint.patch:
  (defvar system-suse-terminfo t) to use TERM=dumb by default
  like GNU Emacs does. The previous default was TERM=emacs, which
  doesn't exist in the latest terminfo.
* Mon Dec 16 2002 mfabian@suse.de
- workaround for fontSet problem in app-defaults:
  use "XEmacs*fontSet:" instead of just "*fontSet:" in the
  app-defaults files.
- workaround to avoid dumping the paths to lisp files
  as /usr/src/packages/BUILD/... into the xemacs executable adapted
  for the portable dumper
* Fri Dec 13 2002 mfabian@suse.de
- add /usr/X11R6/bin/xemacs-%%{version}-*.dmp to file list.
* Fri Dec 13 2002 mfabian@suse.de
- update to 21.4.11rc1
- update Sumo to 2002-09-19
- remove parts of packages-cvs-xemacs-sumo-2002-03-29-ps-print.patch
  which are included upstream
- use portable dumper by default
- fix Makefiles of xslt-process
* Thu Dec 12 2002 coolo@suse.de
- use libndbm instead of libgdbm for non-GNU dbm
* Wed Nov 20 2002 schwab@suse.de
- More autoconf fixes.
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Mon Aug 19 2002 mfabian@suse.de
- quick and dirty fix to make it build again.
  The Makefile in the 'locale' package lists 3 .elc files with
  the same name in different subdirectories. 'make install'
  tries to copy them all into the same destination directory:
  cp -af {ja,ro,fr}/locale-start.elc \
    /usr/share/xemacs/mule-packages/lisp/locale/
  The 'cp' from latest fileutils cowardly refuses to overwrite
  the Japanese and Romanian versions of locale-start.elc with
  the French version, as it did until now.
  But the files in /usr/share/xemacs/mule-packages/lisp/locale/
  are apparently never read anyway, only the files from
  /usr/share/xemacs/mule-packages/etc/start-files/{ja,ro,fr}/
  are read. Therefore I fixed this temporarily by not building
  any locale-start.elc files which prevents installing anything
  into /usr/share/xemacs/mule-packages/lisp/locale/.
- use the correct encoding for the output of
  'LC_ALL=ja_JP.eucJP xemacs --help',
  'LC_ALL=ja_JP.UTF-8 xemacs --help', and
  'LC_ALL=ja_JP.SJIS xemacs --help'.
- similar problem with 'cp' fixed in mule-ucs package
* Fri Aug 16 2002 mfabian@suse.de
- add packages-cvs-xemacs-sumo-2002-05-22-gnus-5.8.8-utf-8.patch
  to make it possible to send Mails in UTF-8 with Gnus 5.8.8.
* Sun Aug 11 2002 mfabian@suse.de
- change # neededforbuild:
  cannadev -> canna canna-devel canna-libs
* Mon Jul 22 2002 werner@suse.de
- diff-mode: check on hunk even if file diff starts (bug #17035)
* Mon Jul 22 2002 werner@suse.de
- Fix path expansion in apel/install.el of sumo tar ball
- Enable RPM_OPT_FLAGS for SuSE Linux version > 8.0
* Fri Jul  5 2002 kukuk@suse.de
- Use %%ix86 macro
* Mon Jun 10 2002 mfabian@suse.de
- small improvement in ps-mule.el patch:
  keep hanglm24.bdf as a fallback if gulim24.bdf doesn't exist.
* Wed May 29 2002 mfabian@suse.de
- update to 21.4.8 + sumo-2002-05-22
- remove lib64.patch, xemacs-21.4.4-printer.el.patch,
  xemacs-21.4.4-moduledir.patch,
  packages-cvs-xemacs-sumo-2002-03-29-xslide.patch, and
  packages-cvs-xemacs-sumo-2002-03-29-liece.patch
  (included upstream)
- add UTF-8 versions of translated app-defaults
- add *fontSet definitions including iso10646-1 fonts to all
  app-defaults.
- add default app-defaults file
  /usr/X11R6/lib/X11/app-defaults/XEmacs to get the same *fontSet
  settings when starting XEmacs in an UTF-8 locale which has no
  translated app-defaults file (e.g. en_US.UTF-8).
- generate the file lists for the .el and .elc files automatically
  in the .spec file
* Mon May  6 2002 schwab@suse.de
- Readd ia64 patch, suitably adapted.
- Fix lib64 configuration.
* Thu May  2 2002 mfabian@suse.de
- fix printing with when (setq ps-multibyte-buffer 'bdf-font)
  is used
* Thu Apr 25 2002 mfabian@suse.de
- update to 21.4.6 + sumo-2002-03-29
- the update broke the build on ppc and axp, fix it.
- Provides += mule-ucs-xemacs Mule-UCS-xemacs,
  Obsoletes += mule-ucs-xemacs Mule-UCS-xemacs
  (Mule-UCS 0.84 is already part of the sumos now).
- remove packages-cvs-xemacs-sumo-2001-07-09-ia64.patch, patched
  file doesn't exist anymore.
- add packages-cvs-xemacs-sumo-2002-03-29-liece.patch and
  packages-cvs-xemacs-sumo-2002-03-29-xslide.patch to fix build
  problems in packages.
- add packages-cvs-xemacs-sumo-2002-03-29-ps-print.patch (some
  fixes for CJK printing and printing with bdf fonts)
- fix file list: some new lisp packages have been added, some
  old ones were removed and there were some mistakes in the file
  list as well.
* Tue Apr 23 2002 aj@suse.de
- Enable building on architectures with lib64.
- Fix compiler flags for x86.
* Thu Apr  4 2002 schwab@suse.de
- Fix missing quotes in configure script.
* Fri Mar  8 2002 kukuk@suse.de
- Fix file list
* Fri Feb 22 2002 werner@suse.de
- Fix bug #13340: use correct lisp macro name of mouse wheel
  screen scrolling.
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Thu Oct 25 2001 mfabian@suse.de
- remove "/site-packages/lisp/term/" directory from load-path
- add --moduledir configure option
- add workaround to avoid dumping the paths to lisp files
  as /usr/src/packages/BUILD/... into the xemacs executable
- add pattch for big-menubar.el (thanks to <schwab@suse.de>)
* Thu Oct 18 2001 mfabian@suse.de
- fix printer.el to make 'generic-print-region' work again
  under Linux like operating systems
* Fri Sep 21 2001 mfabian@suse.de
- fix font-menu.el to make changing fonts with the menu
  possible again.
* Mon Sep 10 2001 aj@suse.de
- Remove extra space in LDFLAGS to allow building on PowerPC and
  alpha.
* Wed Sep  5 2001 werner@suse.de
- FHS: /var/state/xemacs -> /var/lib/xemacs (bug #8678)
* Mon Sep  3 2001 aj@suse.de
- Don't sort relocation entries, otherwise dumping breaks.
* Mon Jul  2 2001 mfabian@suse.de
- update to 21.4.4
- remove redisplay patch (included upstream)
- remove xemacs-sumo-2000-09-04-jde.patch (jde doesn't exist
  anymore in the current sumos)
- remove xemacs-sumo-2000-09-04-mc.patch (included upstream)
- remove xemacs-db3.patch (included upstream)
- rebuild XEmacs packages from the CVS tree instead of using
  the sumo tarballs. This enables us to easily apply patches
  and rebuild all .elc files, which is difficult with the sumos
- remove xemacs-sumo-2000-01-24-vm.patch,
    xemacs-sumo-2000-09-04-ilisp.patch
  (was only needed to fix problems in rebuilding the .elc files,
  not necessary anymore when rebuilding the .elc from CVS).
- move xemacs-sumo-2000-09-04-ispell.patch into
  packages-cvs-xemacs-sumo-2001-07-09.patch
- removed xemacs-ia64.dif (not needed anymore)
- add gpp libgpp to "# neededforbuild" (the packages contain C++
  sources)
- remove "xemacs-21.4.4-info.tar.bz2" to save some space in the
  source rpm (All these info files can be rebuild from the texinfo
  sources in the main source tar ball "xemacs-21.4.4.tar.bz2")
* Thu Jun  7 2001 werner@suse.de
- A long way: Fix trouble with new autoconf
* Thu Jun  7 2001 werner@suse.de
- Make autoconf work again
* Mon May 14 2001 werner@suse.de
- Add mail crypt patch (bug#8300)
* Tue May  8 2001 werner@suse.de
- Move [(shift home)] and [(shift end)] to [(control home)] and
  [(control end)] to be more common with WIN XY.
- Move func-keys load from window-setup-hook to init function of
  xfree of xemacs.
* Thu May  3 2001 werner@suse.de
- Fix typo in crypt.el (bug#7525)
* Fri Apr  6 2001 mfabian@suse.de
- commented out 'ascii-character property changes for 'delete
  and 'backspace in func-keys.el, because this causes problems
  when using the XEmacs <-> Canna interface (Backspace didn't
  cancel the henkan anymore)
* Sun Apr  1 2001 schwab@suse.de
- Fix ia64 support.
- Add support for Berkeley DB3 from CVS.
* Fri Mar 30 2001 werner@suse.de
- Keybinding
  Change [(home)] from beginning-of-buffer to beginning-of-line
  Change [(end)] from end-of-buffer to end-of-line
  Add [(shift home)] for beginning-of-buffer
  Add [(shift end)]  for end-of-buffer
- Basic wheel mouse support
* Thu Mar 15 2001 ro@suse.de
- changed neededforbuild for openldap2
* Thu Mar 15 2001 ro@suse.de
- fixed neededforbuild for openldap
* Mon Feb  5 2001 werner@suse.de
- Add LDAP on configuration
* Mon Feb  5 2001 werner@suse.de
- Security update to 21.1.14
* Mon Jan 22 2001 mfabian@suse.de
- installed pcl-cvs package as well (it was disabled due to
  problems with this packages, but it seems to work fine now,
  so it can be enabled again).
* Tue Nov 21 2000 werner@suse.de
- Remove swapping of kp-separator/kp-decimal because it's
  done in xkbd map for german keyboards
* Tue Nov 21 2000 werner@suse.de
- Move package names
  * from xe_exec to xemacs
  * from xe_lisp to xemacs-el
  * from xe_info to xemacs-info
- Add kvt.el and gnome.el for the terminal kvt and gnome-terminal
- Make ispell.el compatible ispell-emacs-menu.el
* Fri Nov 17 2000 mfabian@suse.de
- Build with support for FreeWnn.
- added redisplay patch important for Japanese
  (see http://www.xemacs.org/list-archives/xemacs-beta/199912/msg00376.html)
* Tue Oct 24 2000 werner@suse.de
- Replace `@AUCDIR' kludge from lisp/auctex/tex-site.el by the
  location of the auctex data directory (etc/auctex/).
- Use a more generally printer setup for auctex.
* Mon Oct 23 2000 aj@suse.de
- Build with X-Face support.
* Sun Sep 17 2000 schwab@suse.de
- Add support for ia64.
- Fix typo in configure.in.
* Fri Sep 15 2000 werner@suse.de
- Dump cl-macs into xemacs to avoid nasty loading messages
- Fix byte compiling of jde, mew, and ilisp packages
* Fri Sep  8 2000 werner@suse.de
- Correct file list
- make tar's bzip2ed
- add xterm Ctrl+cursor keys
- move dif from 2.1.10 to 2.1.12
* Thu Sep  7 2000 aj@suse.de
- Update to XEmacs 21.1.12 and Sumo packages from 2000-09-04.
* Thu Jul 13 2000 mfabian@suse.de
- cannadev is needed for build to get Canna support compiled in.
- added support for international menubars.
* Thu Jun 29 2000 werner@suse.de
- remove circular dependency between xe_exec and xe_info
* Mon May 29 2000 aj@suse.de
- Update to XEmacs 21.1.10 and  current packages (except pcl-cvs
  which has some problems)
* Wed Apr  5 2000 bk@suse.de
- needs automake for update config.{sub,guess} macro
* Tue Apr  4 2000 bk@suse.de
- s390 team added support for s390
* Thu Feb 17 2000 aj@suse.de
- Added Y2k patch for vc, fixed scaled font handling.
* Mon Feb  7 2000 kasal@suse.de
- app-defaults files should be %%config
* Thu Jan 27 2000 ro@suse.de
- specfile: re-done %%setup section for new tar
* Tue Jan 25 2000 werner@suse.de
- New version 21.1.8
  - New tarballs 2000-01-24
  - New fix for vm package
  - /usr/man -> /usr/share/man
* Fri Jan 14 2000 werner@suse.de
- Fix vm package: macros arn't autoloadable by xemacs 21.x
* Wed Dec 22 1999 werner@suse.de
- Uh: install and pack some missed scripts
* Wed Dec  1 1999 werner@suse.de
- Fix pty handling: use glibc extension
* Thu Nov 11 1999 werner@suse.de
- Fix the site-package extension
  * ispell menus
  * xterm/console key mappings
  - Fix font menu: set `ignore scaled fonts' to nil
* Fri Nov  5 1999 werner@suse.de
- Change file list of xe_info and xe_lisp
* Thu Nov  4 1999 werner@suse.de
- Remove libgif from required packages
* Sat Oct 30 1999 ro@suse.de
- modified filelist for nonx86
- removed libz from neededforbuild: it's default
* Fri Oct 29 1999 werner@suse.de
- Remove `with system malloc' because the last patch seems
  to help. Without system malloc we see more speed
* Thu Oct 28 1999 werner@suse.de
- Add patch for glibc and __malloc_hook
* Tue Oct 26 1999 werner@suse.de
- New glibc requires `with system malloc'
* Wed Oct 20 1999 werner@suse.de
- Last checks
* Wed Oct 20 1999 werner@suse.de
- New version 21.1.7
  * avoid locale problems due to lisp formats of time e.g.
  - Use xemacs-mule-sumo-1999-05-27.tar.gz to avoid trouble
  with not synched mule versions of xemacs and mule-sumo
  - Use xemacs-sumo-1999-07-29.tar.gz
  * Many bug fixes due to missed load statements and
  minor version comparision: (19.)13 > (21.)1
  - Add the already used bug fixes and changes
  * security
  * ispell menu
  * dinbrief.el for auctex
  * ...
  - Store xemacs in /usr/share/xemacs/<version>/
  and /usr/<lib>/xemacs/<version>/
  - Move info to /usr/share/xemacs/info/
  - Enable site-lisp and move it to /usr/share/xemacs/site-lisp/
  - Make configured in paths work
* Mon Sep 27 1999 bs@suse.de
- fixed requirements for sub packages
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Fri Aug 13 1999 werner@suse.de 
- fix locale handling of xemacs
  * overwrite LC_NUMERIC, LC_TIME, and LC_MESSAGES to
  "C" to get something what can xemacs can handle
  - fix dinbrief.el
* Mon Apr  5 1999 bs@suse.de
- fixed date strings in .changes.
* Mon Mar  8 1999 werner@suse.de 
- Remove site-lisp/ispell.el* to use the dynamic
  rebuild of the Spell menu of the ispell package
  - Create a site-start.el to do that
* Thu Nov 12 1998 bs@suse.de
- fixed spec file for new rpm.
* Tue Nov  3 1998 werner@suse.de
- Change names of languages and encoding style in ispell
  from `language    (encod)' to `language-encod'
* Tue Jul 28 1998 werner@suse.de
- Do not use system malloc ... some parts of xemacs arn't
  smart enough for that.
  - Disable const
* Mon Jul 27 1998 werner@suse.de
- Use redhat patch for alpha ... means make it work for all
  arch's. This because I do not want use ordinary linkage which
  may causes the troubles seen with xemacs and shared libs.
* Mon Jul 20 1998 werner@suse.de
- use mktemp if avaliable
* Fri Jul 10 1998 werner@suse.de
- Check all script in lib-src against tmp exploits
  - Fix pstogif (exploit and uninitialized variables)
  - Add disp-table to site-load
* Thu Jul  9 1998 werner@suse.de
- Add american to the (i)spell menu
  - Use -fno-force-mem (egcs-bug)
  - Use -rpath-link /usr/X11R6/lib
  - Avoid multiple common
  - Remove and set some CONST
* Wed May 27 1998 werner@suse.de
- Use Xaw3d instead of Xaw to avoid trouble with xaw3dd
  - Change pop service "pop" to "pop3"
* Tue Mar  3 1998 werner@suse.de
- New version 20.4
  - Same changes done for 20.3 (hacked ispell.el for our new ditcs)
  - Fix the change doe for viper-ex.el
  - Remove ctags (own package), send-pr and install-sid (gnats)
  out of /usr/X11R6/bin/
* Wed Feb 11 1998 werner@suse.de
- New version 20.3
  * Dead keys seems to work
  * Now BS and DEL are distinct
  - Some changes, e.g. hacked ispell.el for our new ditcs
* Thu Nov  6 1997 werner@suse.de
- New version 20.2
  - Add XFree86 deadlock keys to x-compose.el and x-iso8859-1.el
  - Some changes
* Fri Jul 18 1997 werner@suse.de
- New patchlevel 19.15pl7
  - Remove one change of a patch to save choosen fonts in
  `save options'
  - Add deadlock keys to x-compose.el and x-iso8859-1.el
* Sun May 25 1997 werner@suse.de
- New version: 19.15
  - some changes in keycode under TERM=xterm (term/xterm.el)
  - info goes to /usr/X11R6/lib/xemacs/info/
* Tue Feb  4 1997 werner@suse.de
- Aufraeumen von term/linux.el und term/xterm.el:
  Statt setzten von delete/backspace wird nun
  delbackspace.el verwendet.
  - Fix in einer Info-Seite
* Thu Jan  2 1997 werner@suse.de
- Neue Version von Xemacs: 19.14
  - Anpassungen  an TERM=linux, TERM=xterm
  - Delete loescht Zeichen unter dem Cursor
